@@ -211,14 +211,8 @@ from polars.functions import (
 )
 from polars.interchange import CompatLevel
 from polars.io import (
-    BasePartitionContext,
     FileProviderArgs,
-    KeyedPartition,
-    KeyedPartitionContext,
     PartitionBy,
-    PartitionByKey,
-    PartitionMaxSize,
-    PartitionParted,
     ScanCastOptions,
     defer,
     read_avro,
@@ -233,6 +227,7 @@ from polars.io import (
     read_ipc_schema,
     read_ipc_stream,
     read_json,
+    read_lines,
     read_ndjson,
     read_ods,
     read_parquet,
@@ -242,6 +237,7 @@ from polars.io import (
     scan_delta,
     scan_iceberg,
     scan_ipc,
+    scan_lines,
     scan_ndjson,
     scan_parquet,
     scan_pyarrow_dataset,
@@ -335,13 +331,7 @@ __all__ = [
     # polars.io
     "defer",
     "FileProviderArgs",
-    "KeyedPartition",
-    "BasePartitionContext",
-    "KeyedPartitionContext",
     "PartitionBy",
-    "PartitionByKey",
-    "PartitionMaxSize",
-    "PartitionParted",
     "ScanCastOptions",
     "read_avro",
     "read_clipboard",
@@ -355,6 +345,7 @@ __all__ = [
     "read_ipc_schema",
     "read_ipc_stream",
     "read_json",
+    "read_lines",
     "read_ndjson",
     "read_ods",
     "read_parquet",
@@ -364,6 +355,7 @@ __all__ = [
     "scan_delta",
     "scan_iceberg",
     "scan_ipc",
+    "scan_lines",
     "scan_ndjson",
     "scan_parquet",
     "scan_pyarrow_dataset",
