@@ -7,7 +7,16 @@ from datetime import date, datetime, time, timedelta
 from decimal import Decimal as PyDecimal
 from inspect import isclass
 from types import NoneType, UnionType
-from typing import TYPE_CHECKING, Any, Final, ForwardRef, NoReturn, get_args
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Final,
+    ForwardRef,
+    NoReturn,
+    Union,
+    get_args,
+    get_origin,
+)
 
 import polars._reexport as pl
 from polars.datatypes.classes import (
@@ -33,9 +42,6 @@ if TYPE_CHECKING:
     from polars._typing import PolarsDataType, PythonDataType, SchemaDict
 
 
-UnionTypeOld = type(int | str)
-
-
 def parse_into_datatype_expr(input: Any) -> pl.DataTypeExpr:
     """Parse an input into a DataTypeExpr."""
     if isinstance(input, pl.DataTypeExpr):
@@ -57,7 +63,7 @@ def parse_into_dtype(input: Any) -> PolarsDataType:
         return input
     elif isinstance(input, ForwardRef):
         return _parse_forward_ref_into_dtype(input)
-    elif isinstance(input, (UnionType, UnionTypeOld)):
+    elif isinstance(input, UnionType) or get_origin(input) is Union:
         return _parse_union_type_into_dtype(input)
     else:
         return parse_py_type_into_dtype(input)
