@@ -8,6 +8,7 @@ from polars.io.delta import read_delta, scan_delta
 from polars.io.iceberg import scan_iceberg
 from polars.io.ipc import read_ipc, read_ipc_schema, read_ipc_stream, scan_ipc
 from polars.io.json import read_json
+from polars.io.lines import read_lines, scan_lines
 from polars.io.ndjson import read_ndjson, scan_ndjson
 from polars.io.parquet import (
     read_parquet,
@@ -16,14 +17,8 @@ from polars.io.parquet import (
     scan_parquet,
 )
 from polars.io.partition import (
-    BasePartitionContext,
     FileProviderArgs,
-    KeyedPartition,
-    KeyedPartitionContext,
     PartitionBy,
-    PartitionByKey,
-    PartitionMaxSize,
-    PartitionParted,
 )
 from polars.io.plugins import _defer as defer
 from polars.io.pyarrow_dataset import scan_pyarrow_dataset
@@ -34,12 +29,6 @@ __all__ = [
     "defer",
     "FileProviderArgs",
     "PartitionBy",
-    "PartitionByKey",
-    "PartitionMaxSize",
-    "PartitionParted",
-    "KeyedPartition",
-    "BasePartitionContext",
-    "KeyedPartitionContext",
     "read_avro",
     "read_clipboard",
     "read_csv",
@@ -52,6 +41,7 @@ __all__ = [
     "read_ipc_schema",
     "read_ipc_stream",
     "read_json",
+    "read_lines",
     "read_ndjson",
     "read_ods",
     "read_parquet",
@@ -61,6 +51,7 @@ __all__ = [
     "scan_delta",
     "scan_iceberg",
     "scan_ipc",
+    "scan_lines",
     "scan_ndjson",
     "scan_parquet",
     "scan_pyarrow_dataset",
