@@ -221,7 +221,7 @@ def read_excel(
     source: FileSource,
     *,
     sheet_id: None = ...,
-    sheet_name: list[str] | tuple[str],
+    sheet_name: list[str] | tuple[str, ...],
     table_name: str | None = ...,
     engine: ExcelSpreadsheetEngine = ...,
     engine_options: dict[str, Any] | None = ...,
@@ -243,7 +243,7 @@ def read_excel(
     source: FileSource,
     *,
     sheet_id: int | Sequence[int] | None = None,
-    sheet_name: str | list[str] | tuple[str] | None = None,
+    sheet_name: str | list[str] | tuple[str, ...] | None = None,
     table_name: str | None = None,
     engine: ExcelSpreadsheetEngine = "calamine",
     engine_options: dict[str, Any] | None = None,
@@ -516,7 +516,7 @@ def read_ods(
     source: FileSource,
     *,
     sheet_id: None = ...,
-    sheet_name: list[str] | tuple[str],
+    sheet_name: list[str] | tuple[str, ...],
     has_header: bool = ...,
     columns: Sequence[int] | Sequence[str] | None = ...,
     schema_overrides: SchemaDict | None = ...,
@@ -532,7 +532,7 @@ def read_ods(
     source: FileSource,
     *,
     sheet_id: int | Sequence[int] | None = None,
-    sheet_name: str | list[str] | tuple[str] | None = None,
+    sheet_name: str | list[str] | tuple[str, ...] | None = None,
     has_header: bool = True,
     columns: Sequence[int] | Sequence[str] | None = None,
     schema_overrides: SchemaDict | None = None,
